AGW Logo

svn SVN Revision 70370 For shapedbutton

This file contains the SVN revision history for shapedbutton, at revision 70370.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 17-Oct-2008 19:15:31 UTC
  • Committer: AG
  • File Size: 68358 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

ShapedButton: fix incorrect KeyCode() (just replace it with GetKeyCode()). Closes ticket #13842.


svn_diff Diff To Previous Version (68881)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/shapedbutton.py       2011/08/25 16:40:17     68881
+++ wxPython/3rdParty/AGW/agw/shapedbutton.py       2012/01/16 20:37:28     70370
@@ -3,7 +3,7 @@
# Python Code By:
#
# Andrea Gavana, @ 18 Oct 2005
# Latest Revision: 17 Aug 2011, 15.00 GMT
#
#
# TODO List/Caveats
@@ -149,7 +149,7 @@

`ShapedButton` is distributed under the wxPython license.

-Latest revision: Andrea Gavana @ 17 Aug 2011, 15.00 GMT
+Latest revision: Andrea Gavana @ 16 Jan 2012, 20.00 GMT

Version 0.4

@@ -859,7 +859,7 @@
:param `event`: a `wx.KeyEvent` event to be processed.
"""

-        if self._hasfocus and event.KeyCode() == ord(" "):
+        if self._hasfocus and event.GetKeyCode() == ord(" "):

self._isup = False
self.Refresh()
@@ -1371,7 +1371,7 @@
:param `event`: a `wx.KeyEvent` event to be processed.
"""

-        if self._hasfocus and event.KeyCode() == ord(" "):
+        if self._hasfocus and event.GetKeyCode() == ord(" "):

self._isup = not self._isup
self.Notify()
@@ -3,7 +3,7 @@
#
# Andrea Gavana, @ 18 Oct 2005
-# Latest Revision: 17 Aug 2011, 15.00 GMT
+# Latest Revision: 16 Jan 2012, 20.00 GMT
#
#
Tree

Table Of Contents

Previous topic

SVN Revision 68881 For shapedbutton

Next topic

shortcuteditor